<?php
/*
Plugin Name: Nút liên hệ | Tinhcau.com
Description: Plugin tạo giao diện các nút liên hệ với tùy chọn trong admin panel.
Version: 1.0
Author: Truyen | Tinhcau.com
*/

if (!defined('ABSPATH')) exit;

add_action('admin_menu', function() {
    add_menu_page('Cài đặt Nút liên hệ', 'Nút liên hệ', 'manage_options', 'nut-lien-he-settings', 'render_nut_lien_he_settings_page', 'dashicons-admin-links');
});

function render_nut_lien_he_settings_page() {
    if (!current_user_can('manage_options')) return;
    if (isset($_POST['nut_lien_he_save_settings'])) {
        update_option('nut_lien_he_settings', $_POST['nut_lien_he_settings']);
        echo '<div class="updated"><p>Lưu thành công!</p></div>';
    }
    $settings = get_option('nut_lien_he_settings', [
        'hotline' => ['text' => 'Hotline', 'phone' => '0911202404', 'icon' => 'https://cdn.tinhcau.com/m/vv/6791cea496a60.png', 'bg' => '#c64448', 'color' => '#fff'],
        'facebook' => ['text' => 'Chat FB', 'url' => 'https://www.facebook.com/truyen.dev', 'icon' => 'https://cdn.tinhcau.com/m/vv/6791ce6d552fe.png', 'bg' => '#007ace', 'color' => '#fff'],
        'zalo' => ['text' => 'Chat Zalo', 'url' => 'https://zalo.me/0911202404', 'icon' => 'https://cdn.tinhcau.com/m/vv/6791ce7fd3d2e.png', 'bg' => '#0067e5', 'color' => '#fff'],
        'contact' => ['text' => 'Liên hệ', 'url' => '#', 'icon' => 'https://cdn.tinhcau.com/m/vv/6791ce9062646.png', 'bg' => '#f46b02', 'color' => '#fff']
    ]);
    ?>
    <div class="wrap">
        <h1>Cài đặt Nút liên hệ</h1>
        <form method="POST">
            <table class="form-table">
                <?php foreach ($settings as $key => $value): ?>
                    <tr>
                        <th><?php echo ucfirst($key); ?></th>
                        <td>
                            <p>Text: <input type="text" name="nut_lien_he_settings[<?php echo $key; ?>][text]" value="<?php echo esc_attr($value['text']); ?>" class="regular-text"></p>
                            <?php if ($key === 'hotline'): ?>
                                <p>Phone: <input type="text" name="nut_lien_he_settings[<?php echo $key; ?>][phone]" value="<?php echo esc_attr($value['phone']); ?>" class="regular-text"></p>
                            <?php else: ?>
                                <p>URL: <input type="url" name="nut_lien_he_settings[<?php echo $key; ?>][url]" value="<?php echo esc_attr($value['url']); ?>" class="regular-text"></p>
                            <?php endif; ?>
                            <p>Icon URL: <input type="url" name="nut_lien_he_settings[<?php echo $key; ?>][icon]" value="<?php echo esc_attr($value['icon']); ?>" class="regular-text"></p>
                            <p>Background Color: <input type="color" name="nut_lien_he_settings[<?php echo $key; ?>][bg]" value="<?php echo esc_attr($value['bg']); ?>"></p>
                            <p>Text Color: <input type="color" name="nut_lien_he_settings[<?php echo $key; ?>][color]" value="<?php echo esc_attr($value['color']); ?>"></p>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
            <p><button type="submit" name="nut_lien_he_save_settings" class="button button-primary">Lưu</button></p>
        </form>
    </div>
    <?php
}

add_action('wp_footer', function() {
    $settings = get_option('nut_lien_he_settings', []);
    if (!$settings) return;
    ?>
    <div id="itv-btn" style="position:fixed;z-index:9999;bottom:0px;right:5px;">
        <div class="itv-btn-group">
            <ul style="list-style:none;padding:0;margin:0;">
                <?php foreach ($settings as $key => $value): ?>
                    <li>
                        <a rel="nofollow" target="_blank" href="<?php echo $key === 'hotline' ? 'tel:' . esc_attr($value['phone']) : esc_url($value['url']); ?>" style="display:flex;align-items:center;padding:5px 10px;background:<?php echo esc_attr($value['bg']); ?>;color:<?php echo esc_attr($value['color']); ?>;text-decoration:none;">
                            <img src="<?php echo esc_url($value['icon']); ?>" alt="<?php echo esc_attr($value['text']); ?>" style="width:20px;height:20px;margin-right:10px;">
                            <span><?php echo esc_html($value['text']); ?></span>
                        </a>
                    </li>
                <?php endforeach; ?>
            </ul>
        </div>
    </div>
    <style>
        #itv-btn {
            font-family: Roboto, sans-serif;
            line-height: 1.5;
        }
.itv-btn-group a {
    border-radius: 99px;
}
.itv-btn-group ul li {
    margin-bottom: 10px;
}
        .itv-btn-group ul li a {
            transition: all 0.3s ease-in-out;
        }
        .itv-btn-group ul li a:hover {
            transform: translateY(-5px);
        }
         @media (max-width: 768px) {
            #itv-btn {
                bottom: 0;
                right: 0;
                left: 0;
                width: 100%;
                background-color: #fff;
                box-shadow: 0 -2px 5px rgba(0, 0, 0, 0.1);
                padding: 0;
            }
            .itv-btn-group ul {
                display: flex;
                justify-content: space-around;
                margin: 0;
            }
            .itv-btn-group ul li {
                flex: 1;
                margin: 0;
            }
            .itv-btn-group ul li a {
                flex-direction: column;
                align-items: center;
                justify-content: center;
                padding: 0;
                height: 70px;
                border-radius: 0;
            }
            .itv-btn-group ul li a img {
                margin-bottom: 5px;
            }
        }
    </style>
    <?php
});